@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2006 Steven L. Scott
 
@@ -18,20 +19,18 @@
 #ifndef BOOM_MVN_GIVEN_SIGMA_HPP
 #define BOOM_MVN_GIVEN_SIGMA_HPP
 
-#include <Models/MvnBase.hpp>
-#include <Models/Policies/SufstatDataPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
-#include <Models/Policies/ParamPolicy_2.hpp>
+#include "Models/MvnBase.hpp"
+#include "Models/Policies/ParamPolicy_2.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "Models/Policies/SufstatDataPolicy.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  class MvnGivenSigma
-    : public MvnBase,
-      public LoglikeModel,
-      public ParamPolicy_2<VectorParams, UnivParams>,
-      public SufstatDataPolicy<VectorData, MvnSuf>,
-      public PriorPolicy
-  {
+  class MvnGivenSigma : public MvnBase,
+                        public LoglikeModel,
+                        public ParamPolicy_2<VectorParams, UnivParams>,
+                        public SufstatDataPolicy<VectorData, MvnSuf>,
+                        public PriorPolicy {
    public:
     //  This model is y | mu, kappa Sigma ~ N(mu, Sigma/kappa)
 
@@ -49,55 +48,52 @@ namespace BOOM{
 
     // See also MvnGivenX.  These priors are similar.  Use this one if
     // X is going to remain fixed, and MvnGivenX if X will change.
+    MvnGivenSigma(const Vector &mu, double kappa);
+    MvnGivenSigma(const Vector &mu, double kappa, const SpdMatrix &Siginv);
+    MvnGivenSigma(const Vector &mu, double kappa, const Ptr<SpdData> &Sigma);
+    MvnGivenSigma(const Ptr<VectorParams> &mu, const Ptr<UnivParams> &kappa);
+    MvnGivenSigma(const Ptr<VectorParams> &mu, const Ptr<UnivParams> &kappa,
+                  const Ptr<SpdData> &Sigma);
 
-    MvnGivenSigma(const Vector &mu, double Kappa);
-    MvnGivenSigma(const Vector &mu, double Kappa, const SpdMatrix & Siginv);
-    MvnGivenSigma(const Vector &mu, double Kappa, Ptr<SpdData> Sigma);
-    MvnGivenSigma(Ptr<VectorParams> mu,
-                  Ptr<UnivParams> Kappa);
-    MvnGivenSigma(Ptr<VectorParams> mu,
-                  Ptr<UnivParams> Kappa,
-                  Ptr<SpdData> Sigma);
+    MvnGivenSigma *clone() const override;
 
-    MvnGivenSigma * clone()const override;
-
-    void set_Sigma(Ptr<SpdData> Sigma);
-    void set_Sigma(const SpdMatrix &V, bool ivar=false);
+    void set_Sigma(const Ptr<SpdData> &Sigma);
+    void set_Sigma(const SpdMatrix &V, bool ivar = false);
 
     Ptr<VectorParams> Mu_prm();
-    const Ptr<VectorParams> Mu_prm()const;
+    const Ptr<VectorParams> Mu_prm() const;
     Ptr<UnivParams> Kappa_prm();
-    const Ptr<UnivParams> Kappa_prm()const;
+    const Ptr<UnivParams> Kappa_prm() const;
 
-    uint dim()const override;
-    const Vector & mu() const override;
-    double kappa()const;
+    uint dim() const override;
+    const Vector &mu() const override;
+    double kappa() const;
 
     void set_mu(const Vector &);
     void set_kappa(double k);
     void mle() override;
     // The argument is a vector with the mean vector first, and then
     // the proportionalyity facctor 'kappa' second.
-    double loglike(const Vector &mu_kappa)const override;
-    double pdf(Ptr<Data>, bool)const;
-    double pdf(Ptr<DataType>, bool)const;
+    double loglike(const Vector &mu_kappa) const override;
+    double pdf(const Ptr<Data> &dp, bool) const;
+    double pdf(const Ptr<DataType> &dp, bool) const;
 
-    double Logp(const Vector &x, Vector &g, Matrix &h, uint nd)const override;
-    Vector sim(RNG &rng = GlobalRng::rng)const override;
+    double Logp(const Vector &x, Vector &g, Matrix &h, uint nd) const override;
+    Vector sim(RNG &rng = GlobalRng::rng) const override;
 
     // overloads required to conform with the MvnBase interface The
     // 'Sigma' here refers to the vaiance, not the Sigma paramter.
     // i.e. Sigma() returns  Sigma/kappa
 
-    const SpdMatrix & Sigma()const override;
-    const SpdMatrix & siginv()const override;
-    double ldsi()const override;
+    const SpdMatrix &Sigma() const override;
+    const SpdMatrix &siginv() const override;
+    double ldsi() const override;
 
    private:
     Ptr<SpdData> Sigma_;
-    void check_Sigma()const;
+    void check_Sigma() const;
     mutable SpdMatrix S;
   };
 
 }  // namespace BOOM
-#endif // BOOM_MVN_GIVEN_SIGMA_HPP
+#endif  // BOOM_MVN_GIVEN_SIGMA_HPP
