@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2008 Steven L. Scott
 
@@ -15,17 +16,17 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <LinAlg/stack_columns.hpp>
-#include <LinAlg/Matrix.hpp>
+#include "LinAlg/stack_columns.hpp"
+#include "LinAlg/Matrix.hpp"
 
-namespace BOOM{
-  Vector stack_columns(const Matrix &m){
+namespace BOOM {
+  Vector stack_columns(const Matrix &m) {
     uint n = m.size();
     Vector ans(n);
     Vector::iterator it = ans.begin();
     uint nc = m.ncol();
-    for(uint i=0; i<nc; ++i)
+    for (uint i = 0; i < nc; ++i)
       it = std::copy(m.col_begin(i), m.col_end(i), it);
     return ans;
   }
-}
+}  // namespace BOOM
